@@ -4,11 +4,12 @@ use 5.008_005;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.11'; # Set automatically by milla
+our $VERSION = '0.12'; # Set automatically by milla
 
 my $based = {
 	'default.base' => 'Rest::HtmlVis::Base',
 	'default.content' => 'Rest::HtmlVis::Content',
+	'default.footer' => 'Rest::HtmlVis::Footer',
 };
 
 sub new {
@@ -54,17 +55,18 @@ sub loadVisObject {
 			object => $vis
 		}) if $vis->isa('Rest::HtmlVis::Key');
 	}else{
-		print STDERR "ERROR: to load vis class".$err."\n";
+		print STDERR "ERROR: to load vis class: ".$err."\n";
 	}
 }
 
 sub html {
-	my ($self, $struct, $env) = @_;
+	my ($self, $struct, $env, $header) = @_;
 
 	### manage keys
 	my $head_parts = '';
 	my $onload_parts = '';
 	my $html_parts = '';
+	my $footer_parts = '';
 
 	my $rowBlocks = 0; # count number of blocks in row
 
@@ -74,6 +76,7 @@ sub html {
 
 			my $vis = $obj->{object};
 			next unless $vis->setStruct($obj->{key}, $struct, $env);
+			$vis->setHeader($header);
 
 			my $head = $vis->head($self->{local});
 			$head_parts .= $head if $head;
@@ -91,6 +94,8 @@ sub html {
 				$html_parts .= '</div>' if $newRow;
 				$rowBlocks = 0 if $newRow;
 			}
+			my $footer = $vis->footer($self->{local});
+			$head_parts .= $footer if $footer;
 		}
 	}
 
@@ -101,7 +106,7 @@ sub html {
 sub _try_load {
 	my $mod = shift;
 
-	return 0 unless $mod;
+	return +(0, "Not defined module.") unless $mod;
 	return 1 if ($mod->can("html")); # because of local class in psgi
 	eval("use $mod; 1") ? return 1 : return (0, $@);
 }
