@@ -23,7 +23,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 
 =head1 SYNOPSIS
@@ -207,6 +207,9 @@ sub html {
 					}
 				  $ret .= "</div><hr />";
 			}
+	my $header = $self->getHeader;
+	my $duration = sprintf ( "%.3f",$header->{'X-Runtime'} *1000);
+
   $ret .= " 			<ul class=\"links\">
 				$links
 			</ul>
@@ -215,6 +218,7 @@ sub html {
 			<pre class=\"prettyprint lang-yaml\">
 $content
 			</pre>
+			<div class=\"row align-right text-muted duration\"> <small>Duration: $duration ms </small></div>  
 		</div>
 		<div class=\"col-lg-3\" role=\"tabpanel\">
 
@@ -256,7 +260,7 @@ END
 my $defaultForm = {
 	get => 	"<label class=\"col-lg-4 control-label\">Get as</label> 
 	<select name=\"format\" class=\"form-control\">
-		<option selected=\"selected\">text/html</option>
+	  <option selected=\"selected\">text/html</option>
 	  <option>application/json</option>
 	  <option>text\/yaml</option>
 	  <option>text/plain</option>
@@ -265,9 +269,9 @@ my $defaultForm = {
 	
 	post => "<label class=\"col-lg-4 control-label\">Get as</label> 
 	<select name=\"format\" class=\"form-control\">
-		<option>text/html</option>
+	  <option selected=\"selected\">text/html</option>
 	  <option>application/json</option>
-	  <option selected=\"selected\">text/yaml</option>
+	  <option>text/yaml</option>
 	  <option>text/plain</option>
 	</select>
 	<label class=\"col-lg-4 control-label\">Post as</label> 
