@@ -14,7 +14,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 
 =head1 SYNOPSIS
@@ -58,6 +58,25 @@ sub baseurl {
 	return $_[0]->{baseurl};
 }
 
+=head2 setHeader
+
+=cut
+
+sub setHeader{
+	my ($self, $header) = @_;
+	my %hash = @{$header};
+	$self->{header} = \%hash;
+}
+
+=head2 getHeader
+
+=cut
+
+sub getHeader {
+	my ($self) = @_;
+	return $self->{header};
+}
+
 =head2 setStruct
 
 =cut
@@ -145,6 +164,19 @@ sub head {
 	return;
 }
 
+=head2 head
+
+Return footer of page as HTML string.
+
+Default empty.
+
+=cut
+
+sub footer {
+	my ($self) = @_;
+	return;
+}
+
 =head2 onload
 
 Return onload javascript function of onload attr in body. It must ends with ;
